@@ -42,9 +42,9 @@
 #include "debug.h"
 #include "platform.h"
 #include "script.h"
+#include "sound.h"
 
 #include <stdio.h> 
-#include <ClanLib/lua.h>
 #include <ClanLib/display.h>
 #include <ClanLib/sound.h>
 #include <ClanLib/network.h>
@@ -98,7 +98,7 @@ int U61_Application::main(int argc, char **argv)
       U61_Platform::init();
 
       U61_Version::get_version_text(buf);
-      U61_LOG_MESSAGE("Starting "<<buf<<"...");
+      U61_LOG_MESSAGE("Starting U61 "<<buf<<" using ClanLib "<<CL_VERSION_STRING<<"...");
 
       try
 	{
@@ -123,6 +123,8 @@ int U61_Application::main(int argc, char **argv)
 
       U61_LOG_MESSAGE("Game over...");
 
+      U61_Sound::wait_no_playback();
+
       U61_Platform::deinit();
       U61_Script::close();
       CL_SetupMikMod::deinit();
@@ -169,7 +171,7 @@ bool U61_Application::process_options(int argc,char **argv)
 	      std::cout<<"U61 - another block-based game\n";
 	      std::cout<<"\n";
 	      std::cout<<"v"<<buf<<" compiled on "<<__DATE__<<" at "__TIME__"\n";
-	      std::cout<<"Copyright (C) 2000-2001 Christian Mauduit\n";
+	      std::cout<<"Copyright (C) 2000-2002 Christian Mauduit\n";
 	      std::cout<<"\n";
 	      std::cout<<"This program is free software; you can redistribute it and/or modify\n";
 	      std::cout<<"it under the terms of the GNU General Public License as published by\n";
