@@ -40,6 +40,7 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
+#include <ClanLib/application.h>
 
 #include "const.h"
 
@@ -51,9 +52,10 @@ class U61_Application : public CL_ClanApplication
 {
 public:	
     virtual char *get_title();
-    virtual int main(int argc, char** argv);
+    virtual int main(int argc, char **argv);
 protected:
     char app_name[U61_CONST_STRING_SIZE];
+    bool process_options(int argc, char **argv);
 };
 
 #endif
