@@ -64,6 +64,8 @@
 #define U61_CLIENTPROTOCOL_PLAYING                  60   
 #define U61_CLIENTPROTOCOL_CLOSED                   61
 
+#define U61_CLIENTPROTOCOL_BROADCAST_TIMEOUT      3000
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -73,12 +75,24 @@
  * creates a client protocol
  */
 U61_ClientProtocol::U61_ClientProtocol(U61_ClientDispatcher *d, 
-				       int p,int ch,
-                                       char *id)
+				       int p, int ch,
+                                       char *id, bool bcast)
   : U61_Protocol(p,ch)
 {
+  char *pos;
+
+  /*
+   * we remove spaces from the server name
+   */
+  pos=strchr(id,' ');
+  if (pos!=NULL)
+    {
+      (*pos)='\0';
+    }
+
   dispatcher=d;
   server_id=id;
+  broadcast=bcast;
   connection=NULL;
 }
 
@@ -158,13 +172,13 @@ int U61_ClientProtocol::send_next_packet()
 	}
       break;
     case U61_CLIENTPROTOCOL_CHANNEL_FOUND:
-      if ((result=send_id(connection))==U61_PROTOCOL_DONE)
+      if ((result=send_program(connection))==U61_PROTOCOL_DONE)
 	{
-	  stage=U61_PROTOCOL_ID_SENT;
-	  U61_LOG_DEBUG("stage=ID_SENT");
+	  stage=U61_PROTOCOL_PROGRAM_SENT;
+	  U61_LOG_DEBUG("stage=PROGRAM_SENT");
 	}
       break;
-    case U61_PROTOCOL_ID_RECEIVED:
+    case U61_PROTOCOL_PROGRAM_RECEIVED:
       if ((result=send_version(connection))==U61_PROTOCOL_DONE)
 	{
 	  stage=U61_PROTOCOL_VERSION_SENT;
@@ -217,11 +231,11 @@ int U61_ClientProtocol::recv_next_packet()
 	  U61_LOG_DEBUG("stage=CHANNEL_FOUND");
 	}
       break;
-    case U61_PROTOCOL_ID_SENT:
-      if ((result=recv_id(connection))==U61_PROTOCOL_DONE)
+    case U61_PROTOCOL_PROGRAM_SENT:
+      if ((result=recv_program(connection))==U61_PROTOCOL_DONE)
 	{  
-	  stage=U61_PROTOCOL_ID_RECEIVED;
-	  U61_LOG_DEBUG("stage=ID_RECEIVED");
+	  stage=U61_PROTOCOL_PROGRAM_RECEIVED;
+	  U61_LOG_DEBUG("stage=PROGRAM_RECEIVED");
 	}
       break;
     case U61_PROTOCOL_VERSION_SENT:
@@ -307,14 +321,26 @@ int U61_ClientProtocol::start_searching()
 {
   int result=U61_PROTOCOL_LATER;
 
+  /*
+   * We mark the protocol as being "connecting". This is usefull because
+   * the "abort" procedure is different
+   */
+  connecting=true;
+
   try 
     {
-      //CL_NetSession::find_session_at(U61_PROTOCOL_GAME_ID,server_id,port);
+      if (broadcast)
+	{
+	  // commented out because the ClanLib functions are broken
+	  //	  CL_Network::find_sessions_broadcast(U61_PROTOCOL_GAME_ID,port);
+	}
       result=U61_PROTOCOL_DONE;
     }
   catch (CL_Error e)
     {
       U61_LOG_WARNING("Find error : "<<e.message.c_str()<<"");
+      diagnostic="unable to broadcast";
+      result=U61_PROTOCOL_FAILED;
     }
 
   return result;
@@ -329,27 +355,57 @@ int U61_ClientProtocol::connect_to_server()
 {
   int result=U61_PROTOCOL_LATER;
 
-  try 
+  session=NULL;
+  if (broadcast)
     {
-      //if (CL_NetSession::peek_session_found())
-      //{
-	  //session=CL_NetSession::receive_session_found(U61_PROTOCOL_TIME);
-	  session=new CL_NetSession(U61_PROTOCOL_GAME_ID,server_id,port);
-	  if (session!=NULL)
-	    {
-              /*
-               * OK, a game has been found
-               */
-              join_delay_start=U61_Time::for_effect();
-	      result=U61_PROTOCOL_DONE;
-	    }
-	  //}
+      try 
+	{
+	  /*
+	   * first case, we have broadcasted servers on the LAN, so
+	   * now we connect on the first of these "broadcasted"
+	   * servers
+	   */
+	  // commented out because the ClanLib functions are broken
+	  //session=CL_Network::receive_session_found
+	  //  (U61_CLIENTPROTOCOL_BROADCAST_TIMEOUT);
+	}
+      catch (CL_Error e)
+	{
+	  U61_LOG_WARNING("Broadcast error : "<<e.message.c_str()<<"");
+	  diagnostic="unable to find server";
+	  result=U61_PROTOCOL_FAILED;
+
+	  session=NULL;
+	}
     }
-  catch (CL_Error e)
+  else
     {
-      U61_LOG_WARNING("Connect error : "<<e.message.c_str()<<"");
+      try 
+	{
+	  /*
+	   * second case, we do not broadcast but call a given
+	   * server, specified by name or ip
+	   */
+	  session=new CL_NetSession(U61_CONST_PROGRAM,server_id,port);
+	}
+      catch (CL_Error e)
+	{
+	  U61_LOG_WARNING("Connect error : "<<e.message.c_str()<<"");
+	  diagnostic="unable to connect on server";
+	  result=U61_PROTOCOL_FAILED;
+
+	  session=NULL;
+	}
+    }
+
+  if (session!=NULL)
+    {
+      /*
+       * OK, a game has been found
+       */
+      join_delay_start=U61_Time::for_effect();
+      result=U61_PROTOCOL_DONE;
     }
-  U61_LOG_DEBUG("find server");
 
   return result;
 }
@@ -570,6 +626,11 @@ int U61_ClientProtocol::recv_time()
  */
 void U61_ClientProtocol::start_game()
 {
+  /*
+   * We mark the protocol as not being connecting to the server
+   */
+  connecting=false;
+
   U61_Global::game.do_network_join(U61_Global::remote_script.code_buffer,
 				   id0,id1,
 				   initial_speed,acceleration,curse_delay,
