@@ -53,8 +53,7 @@
 #include "global.h"
 #include "version.h"
 #include "utils.h"
-
-#include <ClanLib/lua.h>
+#include "inputmonitor.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -343,7 +342,7 @@ void U61_Config::reset()
   player[3].key_next_victim=read_player_int(3,U61_CONFIG_ID_KEY_NEXT_VICTIM, CL_KEY_T);
   player[3].key_use_antidote=read_player_int(3,U61_CONFIG_ID_KEY_USE_ANTIDOTE, CL_KEY_G);
 
-  for (k=0;k<CL_NUM_KEYS;++k)
+  for (k=0;k<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++k)
     {
       key[k].ascii=U61_KEYDEF_ASCII_UNKNOWN;
       strcpy(key[k].label,U61_KEYDEF_LABEL_UNKNOWN);
@@ -585,6 +584,39 @@ void U61_Config::reset()
 
   key[CL_KEY_KP_ENTER].ascii=read_key_int(CL_KEY_KP_ENTER,U61_CONFIG_ID_ASCII,U61_KEYDEF_ASCII_UNKNOWN);
   read_key_str(key[CL_KEY_KP_ENTER].label,CL_KEY_KP_ENTER,U61_CONFIG_ID_LABEL,"KP_ENTER");
+
+  key[CL_KEY_KP_DECIMAL].ascii=read_key_int(CL_KEY_KP_DECIMAL,U61_CONFIG_ID_ASCII,'.');
+  read_key_str(key[CL_KEY_KP_ENTER].label,CL_KEY_KP_ENTER,U61_CONFIG_ID_LABEL,"KP .");
+
+  key[CL_KEY_KP_0].ascii=read_key_int(CL_KEY_KP_0,U61_CONFIG_ID_ASCII,'0');
+  read_key_str(key[CL_KEY_KP_0].label,CL_KEY_KP_0,U61_CONFIG_ID_LABEL,"KP 0");
+
+  key[CL_KEY_KP_1].ascii=read_key_int(CL_KEY_KP_1,U61_CONFIG_ID_ASCII,'1');
+  read_key_str(key[CL_KEY_KP_1].label,CL_KEY_KP_1,U61_CONFIG_ID_LABEL,"KP 1");
+
+  key[CL_KEY_KP_2].ascii=read_key_int(CL_KEY_KP_2,U61_CONFIG_ID_ASCII,'2');
+  read_key_str(key[CL_KEY_KP_2].label,CL_KEY_KP_2,U61_CONFIG_ID_LABEL,"KP 2");
+
+  key[CL_KEY_KP_3].ascii=read_key_int(CL_KEY_KP_3,U61_CONFIG_ID_ASCII,'3');
+  read_key_str(key[CL_KEY_KP_3].label,CL_KEY_KP_3,U61_CONFIG_ID_LABEL,"KP 3");
+
+  key[CL_KEY_KP_4].ascii=read_key_int(CL_KEY_KP_4,U61_CONFIG_ID_ASCII,'4');
+  read_key_str(key[CL_KEY_KP_4].label,CL_KEY_KP_4,U61_CONFIG_ID_LABEL,"KP 4");
+
+  key[CL_KEY_KP_5].ascii=read_key_int(CL_KEY_KP_5,U61_CONFIG_ID_ASCII,'5');
+  read_key_str(key[CL_KEY_KP_5].label,CL_KEY_KP_5,U61_CONFIG_ID_LABEL,"KP 5");
+
+  key[CL_KEY_KP_6].ascii=read_key_int(CL_KEY_KP_6,U61_CONFIG_ID_ASCII,'6');
+  read_key_str(key[CL_KEY_KP_6].label,CL_KEY_KP_6,U61_CONFIG_ID_LABEL,"KP 6");
+
+  key[CL_KEY_KP_7].ascii=read_key_int(CL_KEY_KP_7,U61_CONFIG_ID_ASCII,'7');
+  read_key_str(key[CL_KEY_KP_7].label,CL_KEY_KP_7,U61_CONFIG_ID_LABEL,"KP 7");
+
+  key[CL_KEY_KP_8].ascii=read_key_int(CL_KEY_KP_8,U61_CONFIG_ID_ASCII,'8');
+  read_key_str(key[CL_KEY_KP_8].label,CL_KEY_KP_8,U61_CONFIG_ID_LABEL,"KP 8");
+
+  key[CL_KEY_KP_9].ascii=read_key_int(CL_KEY_KP_9,U61_CONFIG_ID_ASCII,'9');
+  read_key_str(key[CL_KEY_KP_9].label,CL_KEY_KP_9,U61_CONFIG_ID_LABEL,"KP 9");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -686,7 +718,7 @@ bool U61_Config::write()
 					player[pl].key_use_antidote);
 	    } 
 
-	  for (k=0;k<CL_NUM_KEYS;++k)
+	  for (k=0;k<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++k)
 	    {
 	      /*
 	       * We do not save informations about keys which seem
