@@ -48,9 +48,11 @@
 
 #include <stdio.h>
 #include <ClanLib/core.h>
+#include <ClanLib/display.h>
 
 #include "const.h"
 #include "playerconfig.h"
+#include "keyconfig.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -68,6 +70,8 @@ class U61_Config
   U61_Config();
   ~U61_Config();
 
+  bool check_id();
+
   void reset();
   bool read();
   bool write();
@@ -81,6 +85,7 @@ class U61_Config
   char script_file[U61_CONST_STRING_SIZE];
 
   bool fullscreen;
+  bool show_system_info;  
 
   char server_id[U61_CONST_STRING_SIZE];
   int network_port;
@@ -94,10 +99,12 @@ class U61_Config
   int music_volume;
 
   int max_fps;
-  
+
   bool network_anticipation;
 
   U61_PlayerConfig player[U61_CONFIG_NB_PLAYERS];
+  U61_KeyConfig key[CL_NUM_KEYS];
+
 
  protected:
   void read_str(char *buf,char *name,char *def);
@@ -110,6 +117,11 @@ class U61_Config
   bool read_player_bool(int pl,char *name,bool def);
   bool write_player_str(int pl,FILE *file,char *name, char *value); 
   bool write_player_int(int pl,FILE *file,char *name,int value);
+  void read_key_str(char *buf,int k,char *name,char *def);
+  int read_key_int(int k,char *name,int def);
+  bool read_key_bool(int k,char *name,bool def);
+  bool write_key_str(int k,FILE *file,char *name, char *value); 
+  bool write_key_int(int k,FILE *file,char *name,int value);
 };
 
 #endif
