@@ -40,6 +40,7 @@
 
 #include "connection.h"
 #include "debug.h"
+#include "global.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -115,6 +116,8 @@ bool U61_Connection::send(U61_Packet *p)
       try
 	{
 	  session->send(channel,group,message,true);
+
+	  U61_Global::system_info.register_bytes_out(size+4);
 	}
       catch (CL_Error e)
 	{
@@ -150,6 +153,8 @@ bool U61_Connection::send(char *str,int max)
       try
 	{
 	  session->send(channel,group,message,true);
+
+	  U61_Global::system_info.register_bytes_out(size+4);
 	}
       catch (CL_Error e)
 	{
@@ -182,6 +187,8 @@ bool U61_Connection::send(int i)
       try
 	{
 	  session->send(channel,group,message,true);
+
+	  U61_Global::system_info.register_bytes_out(4+4);
 	}
       catch (CL_Error e)
 	{
@@ -211,6 +218,8 @@ bool U61_Connection::send(U61_Event evt)
       try
 	{
 	  session->send(channel,group,message,true);
+
+	  U61_Global::system_info.register_bytes_out(8+4);
 	}
       catch (CL_Error e)
 	{
@@ -261,6 +270,8 @@ bool U61_Connection::recv(U61_Packet *p)
 
 	  p->size=size;
 	  memcpy(p->data,message.data.data(),size);
+
+	  U61_Global::system_info.register_bytes_in(size+4);
 	}
       catch (CL_Error e)
 	{
@@ -300,6 +311,8 @@ bool U61_Connection::recv(char *str,int max)
 
 	  memcpy(str,message.data.data(),size);
 	  str[size]=0;
+
+	  U61_Global::system_info.register_bytes_in(size+4);
 	}
       catch (CL_Error e)
 	{
@@ -342,6 +355,8 @@ bool U61_Connection::recv(int *i)
 		| ((unsigned int) buffer[1])<<8 
 		| ((unsigned int) buffer[0]);
 	    }  
+
+	  U61_Global::system_info.register_bytes_in(size+4);
 	}
       catch (CL_Error e)
 	{
@@ -380,6 +395,8 @@ bool U61_Connection::recv(U61_Event *evt)
 	      evt->unserialize((unsigned char *) message.data.data());
 	      U61_LOG_DEBUG("Event "<<*evt<<" received");
 	    }  
+
+	  U61_Global::system_info.register_bytes_in(size+4);
 	}
       catch (CL_Error e)
 	{
