@@ -42,6 +42,7 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
+#include <ClanLib/network.h>
 
 #include "packet.h"
 #include "event.h"
@@ -53,7 +54,7 @@
 class U61_Connection
 {
 public:
-    U61_Connection(CL_NetGame *g,CL_NetComputer *c, 
+    U61_Connection(CL_NetSession *s,CL_NetComputer c, 
                    int ch, bool give_rights);
     ~U61_Connection();
 
@@ -70,7 +71,7 @@ public:
     bool is_associated(CL_NetComputer *c);
 
 protected:
-    CL_NetGame *game;
+    CL_NetSession *session;
     int channel;
     CL_NetGroup group;    
     bool opened;
