@@ -47,11 +47,16 @@
 #include "const.h"
 #include "debug.h"
 #include "platform.h"
+#include "version.h"
+#include "utils.h"
 
 /*---------------------------------------------------------------------------
  constants
  ---------------------------------------------------------------------------*/
 
+#define U61_DATA_ID_PROGRAM "id/program"
+#define U61_DATA_ID_VERSION "id/version"
+
 #define U61_DATA_ID_PROPERTY_SCREEN_W "property/screen_w"
 #define U61_DATA_ID_PROPERTY_SCREEN_H "property/screen_h"
 
@@ -155,6 +160,7 @@ U61_Data::U61_Data()
    */
   strcpy(initial_dir,U61_Platform::getcwd());
   strcpy(data_dir,U61_Platform::getcwd());
+  strcpy(data_file,"");
 }
 
 /*--------------------------------------------------------------------------*/
@@ -192,6 +198,8 @@ void U61_Data::unload()
       //delete manager;
     }
 
+  chdir_to_initial_dir();
+
   manager=NULL;
 }
 
@@ -210,73 +218,95 @@ bool U61_Data::load1(char *name)
   packed_data=true;
 
   /*
-   * creation of the resource manager, which will be
-   * used to load all the sections
+   * we first cehck that the file exists
    */
-  U61_LOG_MESSAGE("Loading data from \""<<name<<"\".");
-  /*
-   * We use a global try to catch errors from ClanLib's
-   * datafile reader. This try should only catch global
-   * errors such as being unable to find the datafile
-   */
-  try
-    {
-      /*
-       * We check if the datafile is packed (.dat) or directory based (.scr)
-       */
-      len=strlen(name);
-      if (len>4)
-	{
-	  if (strcmp(name+len-4,".scr")==0 || strcmp(name+len-4,".SCR")==0)
-	    {
-	      packed_data=false;
-	      /*
-	       * Now we store in dir the directory where the datafile is.
-	       * Later we will chdir to this directory, otherwise the
-	       * ClanLib datafile reader whill pathetically fail since
-	       * it opens "." as the main parent directory
-	       */
-	      strcpy(data_dir,name);
-	      U61_Platform::keep_dir_only(data_dir);
-	    }
-	}
-
-      manager=new CL_ResourceManager(name,packed_data);
-
-      if (manager!=NULL)
-	{
-	  /*
-	   * We use a another try to catch errors from ClanLib's
-	   * datafile reader.
-	   */
-	  try
-	    {
-	      if (success)
-		{
-		  U61_LOG_DEBUG("Loading properties");
-		  success=success && load_properties();
-		}
-	      if (!success)
-		{
-		  U61_LOG_ERROR("Unknown error reading datafile, step 1");
-		}
-	    }
-	  catch(CL_Error e)
-	    {
-	      success=false;
-	      U61_LOG_ERROR("Error reading datafile, step 1: "<<e.message.c_str());
-	    }
-	}
-      else
-	{
-	  U61_LOG_ERROR("Unknown error creating resource manager, step 1"); 
-	  success=false;
-	}
-    }
-  catch(CL_Error e)
+  if (!U61_Utils::file_exists(name))
     {
       success=false;
-      U61_LOG_ERROR("Error creating resource manager, step 1: "<<e.message.c_str());
+      
+      U61_LOG_ERROR("Unable to load data from \""<<name<<"\" (file does not exist).");
+    }
+  else
+    {
+      /*
+       * creation of the resource manager, which will be
+       * used to load all the sections
+       */
+      U61_LOG_MESSAGE("Loading data from \""<<name<<"\".");
+      /*
+       * We use a global try to catch errors from ClanLib's
+       * datafile reader. This try should only catch global
+       * errors such as being unable to find the datafile
+       */
+      try
+	{
+	  /*
+	   * We check if the datafile is packed (.dat) or directory based (.scr)
+	   */
+	  len=strlen(name);
+	  if (len>4)
+	    {
+	      if (strcmp(name+len-4,".scr")==0 || strcmp(name+len-4,".SCR")==0)
+		{
+		  packed_data=false;
+		}
+	    }
+
+	  /*
+	   * Now we store in dir the directory where the datafile is.
+	   * Later we will chdir to this directory, otherwise the
+	   * ClanLib datafile reader whill pathetically fail since
+	   * it opens "." as the main parent directory.
+	   */
+	  strcpy(data_dir,name);
+	  U61_Platform::keep_dir_only(data_dir);
+	  /*
+	   * We store the name of the datafile, without the path
+	   */
+	  strcpy(data_file,name);
+	  U61_Platform::keep_file_only(data_file);
+
+	  chdir_to_data_dir();
+	  manager=new CL_ResourceManager(data_file,packed_data);
+
+	  if (manager!=NULL)
+	    {
+	      /*
+	       * We use a another try to catch errors from ClanLib's
+	       * datafile reader.
+	       */
+	      try
+		{
+		  if (success)
+		    {
+		      U61_LOG_DEBUG("Checking id");
+		      check_id();
+
+		      U61_LOG_DEBUG("Loading properties");
+		      success=success && load_properties();
+		    }
+		  if (!success)
+		    {
+		      U61_LOG_ERROR("Unknown error reading datafile, step 1");
+		    }
+		}
+	      catch(CL_Error e)
+		{
+		  success=false;
+		  U61_LOG_ERROR("Error reading datafile, step 1: "<<e.message.c_str());
+		}
+	    }
+	  else
+	    {
+	      U61_LOG_ERROR("Unknown error creating resource manager, step 1"); 
+	      success=false;
+	    }
+	}
+      catch(CL_Error e)
+	{
+	  success=false;
+	  U61_LOG_ERROR("Error creating resource manager, step 1: "<<e.message.c_str());
+	}
     }
 
   return success;
@@ -385,6 +415,44 @@ void U61_Data::chdir_to_initial_dir()
 }
 
 
+/*--------------------------------------------------------------------------*/
+/*
+ * checks that the datafile is a correct U61 datafile
+ */
+bool U61_Data::check_id()
+{
+  bool success=true;
+  char *program_read;
+  char *version_read;
+  char version[U61_CONST_STRING_SIZE];
+
+  U61_Version::get_version_text(version);
+
+  program_read=CL_String(U61_DATA_ID_PROGRAM,manager).get_string();
+  version_read=CL_String(U61_DATA_ID_VERSION,manager).get_string();
+
+  if (program_read==NULL || strcmp(program_read,U61_CONST_PROGRAM))
+    {
+      success=false;
+      U61_LOG_WARNING("The theme file does not seem to be a valid U61 theme file, you should check that U61 is correctly installed.");
+    }
+  else
+    {
+      if (version_read==NULL || strcmp(version_read,version))
+	{
+	  success=false;
+	  if (version_read==NULL)
+	    {
+	      version_read="NULL";
+	    }
+	  
+	  U61_LOG_WARNING("The data file version is \""<<version_read<<"\" but the game version is \""<<version<<"\", so you get errors when loading it. Maybe you should just get rid of it and/or reinstall U61.");
+	}
+    }
+
+  return success;    
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * loads global properties 
