@@ -40,6 +40,7 @@
 #include "platform.h"
 #include "const.h"
 #include "global.h"
+#include "version.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -47,13 +48,9 @@
 
 /*--------------------------------------------------------------------------*/
 /*
- * These are buffers where informations are temprorarily written
- * before they are flushed in the files.
+ * This console is used for output under windows
  */
-//strstream *U61_Debug::error=NULL;
-//strstream *U61_Debug::warning=NULL;
-//strstream *U61_Debug::message=NULL;
-//strstream *U61_Debug::trace=NULL;
+CL_ConsoleWindow *U61_Debug::console;
 
 /*---------------------------------------------------------------------------
  functions
@@ -65,6 +62,20 @@
  */
 void U61_Debug::init()
 {
+  char buf[U61_CONST_STRING_SIZE];        
+  char console_name[U61_CONST_STRING_SIZE];        
+    
+  U61_Version::get_version_text(buf);
+  sprintf(console_name,
+	  "U61 %s log window",
+	  buf);
+
+  console=new CL_ConsoleWindow(console_name);
+  if (console!=NULL)
+    {
+      console->redirect_stdio();
+    }
+
   U61_Global::data.chdir_to_initial_dir();
   U61_Platform::open_log_files();
   U61_Global::data.chdir_to_data_dir();
@@ -77,6 +88,13 @@ void U61_Debug::init()
 void U61_Debug::deinit()
 {
   U61_Platform::close_log_files();
+
+  if (console!=NULL)
+    {
+      //console->display_close_message();
+      delete console;
+      console=NULL;
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -88,6 +106,18 @@ void U61_Debug::flush()
 
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Displays a "press <ENTER> to close message under windows
+ */
+void U61_Debug::display_close_message()
+{
+  if (console)
+    {
+      console->display_close_message();
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * Called within the U61_LOG_ERROR macro
@@ -111,7 +141,7 @@ void U61_Debug::log_error(ostrstream &s)
 #endif
 
   buffer[len]=0;
-  cerr<<"u61: ERROR! "<<buffer<<"\n";
+  std::cerr<<"u61: ERROR! "<<buffer<<"\n";
   U61_Platform::log_to_error_file(buffer);
 }
 
@@ -138,7 +168,7 @@ void U61_Debug::log_warning(ostrstream &s)
 #endif
 
   buffer[len]=0;
-  cerr<<"u61: WARNING! "<<buffer<<"\n";
+  std::cerr<<"u61: WARNING! "<<buffer<<"\n";
   U61_Platform::log_to_warning_file(buffer);
 }
 
@@ -165,7 +195,7 @@ void U61_Debug::log_message(ostrstream &s)
 #endif
 
   buffer[len]=0;
-  cout<<"u61: "<<buffer<<"\n";
+  std::cout<<"u61: "<<buffer<<"\n";
   U61_Platform::log_to_message_file(buffer);
 }
 
@@ -192,7 +222,7 @@ void U61_Debug::log_debug(ostrstream &s,char *file,int line)
 #endif
 
   buffer[len]=0;
-  //cout<<"U61 debug: "<<buffer<<" (from "<<file<<":"<<line<<")\n";
+  //std::cout<<"U61 debug: "<<buffer<<" (from "<<file<<":"<<line<<")\n";
   U61_Platform::log_to_debug_file(buffer,file,line);
 }
 
