@@ -44,12 +44,12 @@
  * use #defines to include strstrea.h instead of strstream.h 8-(
  */
 #ifdef U61_MSVC
-#include <strstrea.h>
+#include <strstream>
 #else
 #include <strstream.h>
 #endif
 
-#include <fstream.h>
+//#include <fstream>
 
 #include <ClanLib/core.h>
 
@@ -57,11 +57,11 @@
  macros
  ---------------------------------------------------------------------------*/
 
-#define U61_LOG_ERROR(M) {ostrstream s;s<<M;U61_Debug::log_error(s);}
+#define U61_LOG_ERROR(M) {ostrstream s;s<<__FILE__<<":"<<__LINE__<<" "<<M;U61_Debug::log_error(s);}
 #define U61_LOG_WARNING(M) {ostrstream s;s<<M;U61_Debug::log_warning(s);}
 #define U61_LOG_MESSAGE(M) {ostrstream s;s<<M;U61_Debug::log_message(s);}
 #ifdef DEBUG
-#define U61_LOG_DEBUG(M) {ostrstream s;s<<M;U61_Debug::log_debug(s,__FILE__,__LINE__);}
+#define U61_LOG_DEBUG(M) {ostrstream s;s<<__FILE__<<":"<<__LINE__<<" "<<M;U61_Debug::log_debug(s,__FILE__,__LINE__);}
 #else
 #define U61_LOG_DEBUG(M)
 #endif
@@ -90,3 +90,4 @@ protected:
 #endif
 
 
+
