@@ -47,7 +47,7 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
-#include <iostream.h>
+//#include <iostream.h>
 
 #define U61_EVENT_NOTHING            0
 
