@@ -85,7 +85,7 @@ void U61_EventSource::poll()
  */
 void U61_EventSource::reset()
 {
-    last_time_used=-1;
+    last_time_used=0;
     queue.clear();
 }
 
@@ -135,7 +135,7 @@ U61_Event U61_EventSource::check()
  */
 void U61_EventSource::put(U61_Event evt)
 {
-    if (((int)(evt.time))<last_time_used)
+    if (evt.time<last_time_used)
     {
         evt.time=last_time_used;
     }
