@@ -65,7 +65,7 @@ protected:
     void put(U61_Event evt);
 private:
     unsigned int last_time_used;
-    list<U61_Event> queue;  
+    std::list<U61_Event> queue;  
 };
 
 #endif
