@@ -58,17 +58,17 @@ class U61_FileMenu : public U61_Menu
 {
  public:
   U61_FileMenu(U61_Menu *parent, char *top,
-	       char *dir, char *local_dir, char *ext,
+	       char *dir, char *local_dir, 
+	       char *ext1,char *ext2,char *ext3,
                char *choice);    
     
  protected:
   int last_selection;
-  char *extension;
   bool empty;
   int last_added;
   char *chosen_file;
 
-  bool add_files(char *dir);
+  bool add_files(char *dir,char *ext);
 
 };
 
