@@ -186,7 +186,7 @@ void U61_Game::run()
   state=U61_GAME_STATE_RUN;
   slow_down_allowed=true;
   last_display_too_slow=false;
-    
+
   bind_keys();
   reset_players();
 
@@ -330,6 +330,7 @@ void U61_Game::poll()
   int clanlib_time;
   int u61_time;
 
+  CL_System::keep_alive();
   clanlib_time=CL_System::get_time();
   if (last_clanlib_time_polled<clanlib_time)
     {
@@ -367,6 +368,7 @@ void U61_Game::poll()
 
 	  menu_input.poll(u61_time);
           menu_input.poll_mouse();
+	  current_menu->poll();
 
 	  calls_to_poll_menu++;     
         }
