@@ -43,9 +43,12 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- static variables
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_INPUTMONITOR_FIRST_ASCII 32 
+#define U61_INPUTMONITOR_LAST_ASCII 127
+
 /*---------------------------------------------------------------------------
  methods
  ---------------------------------------------------------------------------*/
@@ -68,10 +71,10 @@ void U61_InputMonitor::init()
 {
   device = CL_Input::keyboards[0];
 
-  slot_button_press = CL_Input::sig_button_press.connect
-		 (CL_CreateSlot(this, &U61_InputMonitor::on_button_press));
-  slot_button_release = CL_Input::sig_button_release.connect
-		 (CL_CreateSlot(this, &U61_InputMonitor::on_button_release));
+  slot_button_press = CL_Input::sig_button_press().connect
+		 (this, &U61_InputMonitor::on_button_press);
+  slot_button_release = CL_Input::sig_button_release().connect
+		 (this, &U61_InputMonitor::on_button_release);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -90,15 +93,17 @@ void U61_InputMonitor::read_config(U61_Config *conf)
 {
   int i;
 
-  for (i=0;i<96;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_ASCII;++i)
     {
-      ascii_labels[2*i]=32+i;
+      ascii_labels[2*i]=U61_INPUTMONITOR_FIRST_ASCII+i;
       ascii_labels[2*i+1]=0;
-      ascii[i].define(32+i,ascii_labels+2*i,CL_KEY_NONE_OF_THE_ABOVE);
+      ascii[i].define(U61_INPUTMONITOR_FIRST_ASCII+i,
+		      ascii_labels+2*i,
+		      CL_KEY_NONE_OF_THE_ABOVE);
     }
   ascii[0].define(' ',"SPACE",CL_KEY_NONE_OF_THE_ABOVE);
 
-  for (i=0;i<CL_NUM_KEYS;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++i)
     {
       U61_LOG_DEBUG("reading from config, key scancode="<<i<<", ascii="<<((int) conf->key[i].ascii)<<", label=\""<<conf->key[i].label<<"\"");
 
@@ -114,7 +119,7 @@ void U61_InputMonitor::write_config(U61_Config *conf)
 {
   int i;
 
-  for (i=0;i<CL_NUM_KEYS;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++i)
     {    
       conf->key[i].ascii=scancode[i].get_ascii();
       strcpy(conf->key[i].label,scancode[i].get_label());
@@ -131,11 +136,11 @@ void U61_InputMonitor::reset()
 {
   int i;
 
-  for (i=0;i<96;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_ASCII;++i)
     {
       ascii[i].reset();
     }
-  for (i=0;i<CL_NUM_KEYS;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++i)
     {
       scancode[i].reset();
     }
@@ -149,13 +154,13 @@ bool U61_InputMonitor::is_pressed(int key)
 {
   bool result=false;
 
-  if (key<CL_NUM_KEYS)
+  if (key<U61_INPUTMONITOR_NUM_KEYS_SCANCODE)
     {
       result=scancode[key].get_state();
     }
   else
     {
-      result=ascii[key-CL_NUM_KEYS].get_state();
+      result=ascii[key-U61_INPUTMONITOR_NUM_KEYS_SCANCODE].get_state();
     }
 
   return result;
@@ -169,9 +174,9 @@ char U61_InputMonitor::to_ascii(int key)
 {
   char result=U61_KEYDEF_ASCII_UNKNOWN;
 
-  if (key>=CL_NUM_KEYS)
+  if (key>=U61_INPUTMONITOR_NUM_KEYS_SCANCODE)
     {
-      result=ascii[key-CL_NUM_KEYS].get_ascii();
+      result=ascii[key-U61_INPUTMONITOR_NUM_KEYS_SCANCODE].get_ascii();
     }
   else
     {
@@ -189,7 +194,7 @@ int U61_InputMonitor::to_scancode(int key)
 {
   int result=CL_KEY_NONE_OF_THE_ABOVE;
 
-  if (key<CL_NUM_KEYS)
+  if (key<U61_INPUTMONITOR_NUM_KEYS_SCANCODE)
     {
       return key;
     }
@@ -205,9 +210,9 @@ char *U61_InputMonitor::to_label(int key)
 {
   char *result=U61_KEYDEF_LABEL_UNKNOWN;
 
-  if (key>=CL_NUM_KEYS)
+  if (key>=U61_INPUTMONITOR_NUM_KEYS_SCANCODE)
     {
-      result=ascii[key-CL_NUM_KEYS].get_label();
+      result=ascii[key-U61_INPUTMONITOR_NUM_KEYS_SCANCODE].get_label();
     }
   else
     {
@@ -239,7 +244,7 @@ void U61_InputMonitor::on_button_press(CL_InputDevice *device,
    * both AZERTY and QWERTY keyboards at home, and I like it when
    * games know how to make the difference).
    */
-  if (id<CL_KEY_NONE_OF_THE_ABOVE)
+  if (id!=CL_KEY_NONE_OF_THE_ABOVE)
     {
       scancode[id].press(id,asc);
     }
@@ -251,10 +256,12 @@ void U61_InputMonitor::on_button_press(CL_InputDevice *device,
    * codes, but everyone thinks of the key as being 1 2 or 6.
    * So numbers are polled by their scancode, that's the point.
    */ 
-  else if (asc>32 && asc<=127 && 
-      !(id>=CL_KEY_0 && id<=CL_KEY_9))
+  else if (asc != ' '
+	   && asc>=U61_INPUTMONITOR_FIRST_ASCII 
+	   && asc<=U61_INPUTMONITOR_LAST_ASCII && 
+	   !(id>=CL_KEY_0 && id<=CL_KEY_9))
     {
-      ascii[asc-32].press(id,asc);
+      ascii[asc-U61_INPUTMONITOR_FIRST_ASCII].press(id,asc);
     }
 }
 
@@ -281,7 +288,7 @@ void U61_InputMonitor::on_button_release(CL_InputDevice *device,
    * both AZERTY and QWERTY keyboards at home, and I like it when
    * games know how to make the difference).
    */ 
-  if (id<CL_KEY_NONE_OF_THE_ABOVE)
+  if (id!=CL_KEY_NONE_OF_THE_ABOVE)
     { 
       scancode[id].release(id,asc);
     }
@@ -293,10 +300,12 @@ void U61_InputMonitor::on_button_release(CL_InputDevice *device,
    * codes, but everyone thinks of the key as being 1 2 or 6.
    * So numbers are polled by their scancode, that's the point.
    */ 
-  else if (asc>32 && asc<=127 && 
-      !(id>=CL_KEY_0 && id<=CL_KEY_9))
+  else if (asc != ' '
+	   && asc>=U61_INPUTMONITOR_FIRST_ASCII 
+	   && asc<=U61_INPUTMONITOR_LAST_ASCII && 
+	   !(id>=CL_KEY_0 && id<=CL_KEY_9))
     {
-      ascii[asc-32].release(id,asc);
+      ascii[asc-U61_INPUTMONITOR_FIRST_ASCII].release(id,asc);
     }
 
   /*
@@ -309,16 +318,16 @@ void U61_InputMonitor::on_button_release(CL_InputDevice *device,
    * when it should not have been released, but this is much less
    * annoying than having a key permanently pressed...
    */
-  if (id<CL_KEY_NONE_OF_THE_ABOVE)
+  if (id!=CL_KEY_NONE_OF_THE_ABOVE)
     {
-      for (i=0;i<CL_NUM_KEYS;++i)
+      for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++i)
 	{
 	  if (scancode[i].get_scancode()==id)
 	    {
 	      scancode[i].release(id,asc);
 	    }
 	}
-      for (i=0;i<96;++i)
+      for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_ASCII;++i)
 	{
 	  if (ascii[i].get_scancode()==id)
 	    {
@@ -336,12 +345,12 @@ void U61_InputMonitor::check()
 {
   int i;
 
-  for (i=0;i<96;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_ASCII;++i)
     {
       ascii[i].check();
     }
 
-  for (i=0;i<CL_NUM_KEYS;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS_SCANCODE;++i)
     {
       scancode[i].check();
     }
