@@ -53,7 +53,16 @@
  constants
  ---------------------------------------------------------------------------*/
 
-#define U61_INPUTMONITOR_NUM_KEYS 96+CL_NUM_KEYS
+#define U61_INPUTMONITOR_NUM_KEYS_ASCII 96
+#if (CL_NUM_KEYS<CL_KEY_KP_9)
+#define U61_INPUTMONITOR_NUM_KEYS_SCANCODE CL_KEY_KP_9+1
+#else
+#define U61_INPUTMONITOR_NUM_KEYS_SCANCODE CL_NUM_KEYS
+#endif
+
+#define U61_INPUTMONITOR_NUM_KEYS \
+U61_INPUTMONITOR_NUM_KEYS_ASCII + \
+U61_INPUTMONITOR_NUM_KEYS_SCANCODE
 
 /*---------------------------------------------------------------------------
  classes
@@ -79,9 +88,9 @@ class U61_InputMonitor
   void check();
 
  protected:
-  U61_KeyDef ascii[96];
-  U61_KeyDef scancode[CL_NUM_KEYS];
-  char ascii_labels[96*2];  
+  U61_KeyDef ascii[U61_INPUTMONITOR_NUM_KEYS_ASCII];
+  U61_KeyDef scancode[U61_INPUTMONITOR_NUM_KEYS_SCANCODE];
+  char ascii_labels[U61_INPUTMONITOR_NUM_KEYS_ASCII*2];  
 
   CL_Slot slot_button_press;
   CL_Slot slot_button_release;
