@@ -63,7 +63,6 @@
 U61_JoinMenu::U61_JoinMenu(U61_Menu *parent)
   : U61_Menu(parent,"Choose your server")
 {
-  //  add_item(new U61_Button("Join local server"));
   add_item(new U61_Button("Join server"));
   add_item(new U61_EditAddress("Server",U61_Global::config.server_id));
   select(0);
@@ -80,15 +79,6 @@ U61_Menu *U61_JoinMenu::validate()
   next_menu=this;
   switch (selection)
     {
-      /*
-    case 0:
-      next_menu=new U61_NonPausingMenu
-      	(new U61_NetworkMenu
-	 (new U61_SaveScriptMenu
-	  (new U61_ScoreMenu(this))));
-      U61_Global::game.start_network_broadcast();
-      break;
-      */
     case 0:
       next_menu=new U61_NonPausingMenu
 	(new U61_NetworkMenu
