@@ -151,7 +151,7 @@ bool U61_KeyChoose::is_modal()
  * registers a key map. the MenuInput object will be used to get scancodes
  * from ascii codes
  */
-void U61_KeyChoose::register_key_map(U61_MenuInput *map)
+void U61_KeyChoose::register_key_map(U61_MenuInput *km)
 {
-  key_map=map;
+  key_map=km;
 }
