@@ -40,8 +40,20 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#include <string.h>
+#include <stdio.h>
+
+#include <ClanLib/core.h>
+#include <ClanLib/display.h>
+
 #include "keydef.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_KEYDEF_CHECK_DELAY 1000
+
 /*---------------------------------------------------------------------------
  methods
  ---------------------------------------------------------------------------*/
@@ -52,7 +64,9 @@
  */ 
 U61_KeyDef::U61_KeyDef()
 {
-  define('?',"unknown");
+  define(U61_KEYDEF_ASCII_UNKNOWN,
+	 U61_KEYDEF_LABEL_UNKNOWN,
+	 CL_KEY_NONE_OF_THE_ABOVE);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -71,19 +85,34 @@ void U61_KeyDef::reset()
 {
   key_state=false;
   key_flag=false;
+  last_time=0;
 }
 
 /*--------------------------------------------------------------------------*/
 /* 
  * Sets the parameters of a keydef
  */ 
-void U61_KeyDef::define(int ascii, char *label)
+void U61_KeyDef::define(int ascii, char *label,int scancode)
 {
   key_ascii=ascii;
-  key_label=label;
+  strncpy(key_label,label,U61_CONST_STRING_SIZE);
+  key_label[U61_CONST_STRING_SIZE-1]='\0';
+  key_scancode=scancode;
+
+  update_label();
+
   reset();
 }
 
+/*--------------------------------------------------------------------------*/
+/* 
+ * Returns the scancode code of a keydef
+ */ 
+int U61_KeyDef::get_scancode()
+{
+  return key_scancode;
+}
+
 /*--------------------------------------------------------------------------*/
 /* 
  * Returns the ascii code of a keydef
@@ -122,25 +151,95 @@ bool U61_KeyDef::get_state()
   return result;
 }
 
+/*--------------------------------------------------------------------------*/
+/* 
+ * Updates the label accordingly to the ascii value
+ */ 
+void U61_KeyDef::update_label()
+{
+  if (key_ascii>32 && key_ascii<=127)
+    {
+      if (isalnum(key_ascii))
+	{
+	  if (key_scancode>=CL_KEY_0 && key_scancode<=CL_KEY_9)
+	    {
+	      /*
+	       * Now for numbers we have a very special behavior:
+	       * we always write the number whatever the ascii code
+	       * might be. This is usefull for in the key settings
+	       * menu, people remember much more easily of 1,2,3
+	       * than of !, @ or #... And at the same time, we _must_
+	       * allow the user to type those characters for for
+	       * instance on azerty keyboards, you can't type "-" if
+	       * you can't shift numbers 8-(
+	       */
+	      sprintf(key_label,"%d",key_scancode-CL_KEY_0);
+	    }
+	  else
+	    {
+	      sprintf(key_label,"%c",key_ascii);
+	    }
+	}
+      else
+	{
+	  if (key_scancode>=CL_KEY_NONE_OF_THE_ABOVE)
+	    {
+	      sprintf(key_label,"%c (ascii %d)",key_ascii,key_ascii);
+	    }
+	}
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /* 
  * Acknowledges a press on the key
  */ 
-void U61_KeyDef::press()
+void U61_KeyDef::press(int scancode,int ascii)
 {
   key_flag=true;
   key_state=true;
+
+  last_time=CL_System::get_time();
+
+  if (ascii>=0)
+    {
+      key_ascii=ascii;
+    }
+  key_scancode=scancode;
+
+  update_label();
 }
 
 /*--------------------------------------------------------------------------*/
 /* 
  * Acknowledges a release of the key
  */ 
-void U61_KeyDef::release()
+void U61_KeyDef::release(int scancode,int ascii)
 {
   key_state=false;
+
+  last_time=0;
+
+  if (ascii>=0)
+    {
+      key_ascii=ascii;
+    }
+  key_scancode=scancode;
+
+  update_label();
+}
+
+/*--------------------------------------------------------------------------*/
+/* 
+ * Performs a check on the key: if it has not been pressed recently but
+ * is still marked as being pressed, we force it to "unpressed"
+ */ 
+void U61_KeyDef::check()
+{
+  if (key_state && last_time<CL_System::get_time()-U61_KEYDEF_CHECK_DELAY)
+    {
+      release(key_scancode,key_ascii);
+    }
 }
 
 
-
-
