@@ -466,7 +466,7 @@ void U61_Layout::prepare_background()
 {
   int i;
   
-#ifdef U61_MSVC
+#ifndef U61_PREPARE_BACKGROUND
   /*
    * Now I had problems with Visual C++ and Canvas. Maybe this is only
    * a temporary ClanLib limitation since this problem happened with
