@@ -47,9 +47,10 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- globals
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_LOCALSOURCE_DUMMY_DELAY 10
 
 /*---------------------------------------------------------------------------
  functions
@@ -104,7 +105,7 @@ void U61_LocalSource::send_start_stop(int time)
   evt.time=time;
   evt.author=player;
   evt.target=player;
-  evt.code=U61_Event::START_STOP;
+  evt.code=U61_EVENT_START_STOP;
   put(evt); 
   send_name(time);
 }
@@ -123,7 +124,7 @@ void U61_LocalSource::poll_input()
       evt.author=player;
       evt.target=player;
       put(evt);
-      if (evt.code==U61_Event::START_STOP)
+      if (evt.code==U61_EVENT_START_STOP)
 	{
 	  send_name(evt.time);
 	}
@@ -152,7 +153,7 @@ void U61_LocalSource::poll_map()
        * of the dispatcher. This is to avoid the sending of a
        * zillion events if a player has been playing for hours 8-)
        */
-      if (evt.code==U61_Event::LOOSE)
+      if (evt.code==U61_EVENT_LOOSE)
 	{
 	  send_name(evt.time);
 	}
@@ -187,10 +188,10 @@ void U61_LocalSource::poll_dummy()
   U61_Event evt;
 
   dummy_counter++;
-  if (dummy_counter>=DUMMY_DELAY)
+  if (dummy_counter>=U61_LOCALSOURCE_DUMMY_DELAY)
     {
       dummy_counter=0; 
-      evt.code=U61_Event::NOTHING;
+      evt.code=U61_EVENT_NOTHING;
       evt.time=U61_Time::for_event();
       put(evt);
     } 
@@ -213,7 +214,7 @@ void U61_LocalSource::send_name(int time)
   evt.time=time;
   evt.author=player;
   evt.target=player;
-  evt.code=U61_Event::NAME_LETTER;
+  evt.code=U61_EVENT_NAME_LETTER;
 
   while ((c=*(str++))!=0)
     {
