@@ -61,7 +61,7 @@
 char *U61_Menu::bottom_message[U61_MENU_BOTTOM_MESSAGE_NB]=
 {
   "U61, another block-based game by U-Foot",
-  "Copyright (C) 2000-2001 Christian Mauduit",
+  "Copyright (C) 2000-2002 Christian Mauduit",
   "Home page http://www.ufoot.org/u61",
   "Contact author : ufoot@ufoot.org",
   "U61 uses ClanLib http://clanlib.org",
@@ -341,6 +341,16 @@ void U61_Menu::before_first_draw()
 
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * This function is called on a regular basis, and can be redefined
+ * to handle dynamic menus such as the server list.
+ */
+void U61_Menu::poll()
+{
+
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the height of the menu
