@@ -43,10 +43,6 @@ public:
     int get_mouse_y();
 
 protected:
-    const static int MOUSE_DELAY=50;
-    const static int REPEAT_FIRST=50;
-    const static int REPEAT_STANDARD=15;
-
     int mouse_last_fired;
     int mouse_y;
 };
