@@ -45,6 +45,10 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#ifdef U61_MSVC
+#include <minmax.h>
+#endif
+
 #include "menuitem.h"
 #include "global.h"
 #include "letter.h"
@@ -252,7 +256,7 @@ void U61_MenuItem::unselect()
  */
 void U61_MenuItem::set_text(char *str)
 {
-  char old[U61_STRING_SIZE];
+  char old[U61_CONST_STRING_SIZE];
 
   /*
    * Before we empty the queue of letters and refill it with some new,
