@@ -85,6 +85,13 @@ void U61_Music::start()
 {
   int volume;
 
+  /*
+   * Without this call playback fails... Looks like there's an
+   * infinite loop on the last chunk of music, so we force a
+   * delete/new on the sound buffer session.
+   */
+  stop();
+
   if (session==NULL)
     {
       change(true);
@@ -99,10 +106,7 @@ void U61_Music::start()
 	  session->set_volume(2.0*((float) volume)
 			      /((float) U61_MUSIC_VOLUME_MAX));
 	  session->set_position(0);
-	  if (!session->is_playing())
-	    {
-	      session->play();
-	    }
+	  session->play();
 	}
     }
 }
