@@ -40,7 +40,6 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
-#include <ClanLib/lua.h>
 #include <ClanLib/display.h>
 #include <ClanLib/sound.h>
 #include <ClanLib/network.h>
@@ -58,6 +57,7 @@
 #include "const.h"
 #include "debug.h"
 #include "script.h"
+#include "sound.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -92,18 +92,16 @@ static char *scan_ext=NULL;
  * This array contains some typical paths where the game could be installed.
  * In case the path specified in the config file fails, we try all these
  * paths. This way the game with still work even if the player has a static
- * binary exe that is installed in /usr/bin and a custome built datafile
+ * binary exe that is installed in /usr/games and a custome built datafile
  * which is in /usr/local/share...
  */
-#define NB_STANDARD_PATHS 6
+#define NB_STANDARD_PATHS 4
 static char *standard_paths[NB_STANDARD_PATHS]=
 {
-  "../share/u61/",
-  U61_INSTALL_DATA_PATH,
-  "/usr/local/share/u61/",
-  "/usr/share/u61/",
+  "./data/builtin/",
   "/usr/local/share/games/u61/",
-  "/usr/share/games/u61/"
+  "/usr/share/games/u61/",
+  "../share/games/u61/",
 };
 
 /*---------------------------------------------------------------------------
@@ -245,7 +243,7 @@ char *U61_Platform::get_data_path()
     {  
       /*
        * If we are here it means the path in the config file does not
-       * exist. OK, than we'll try something else!
+       * exist. OK, then we'll try something else!
        */
       for (i=0;i<NB_STANDARD_PATHS;++i)
 	{
@@ -510,6 +508,8 @@ void U61_Platform::exec(char *file)
 
   U61_LOG_MESSAGE("Restarting...");
 
+  U61_Sound::wait_no_playback();
+
   U61_Platform::deinit();
   U61_Script::close();
   CL_SetupMikMod::deinit();
