@@ -50,12 +50,12 @@
 #include <ClanLib/sound.h>
 #include <ClanLib/display.h>
 #include <ClanLib/mikmod.h>
-#include <ClanLib/lua.h>
 
 #include "platform.h"
 #include "const.h"
 #include "debug.h"
 #include "script.h"
+#include "sound.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -544,6 +544,8 @@ void U61_Platform::exec(char *file)
 
   U61_LOG_MESSAGE("Restarting...");
 
+  U61_Sound::wait_no_playback();
+
   U61_Platform::deinit();
   U61_Script::close();
   CL_SetupMikMod::deinit();
