@@ -69,6 +69,7 @@ U61_Protocol::U61_Protocol(int p,int c)
   port=p;
   channel=c;
   session=NULL;
+
   reset();
 }
 
@@ -120,9 +121,16 @@ int U61_Protocol::recv_next_packet()
  */
 int U61_Protocol::send_all()
 {
-  int result;
+  int result=U61_PROTOCOL_LATER;
 
-  while ((result=send_next_packet())==U61_PROTOCOL_DONE);
+  if (!failed)
+    {  
+      while ((result=send_next_packet())==U61_PROTOCOL_DONE);
+      if (result==U61_PROTOCOL_FAILED)
+	{
+	  failed=true;
+	}
+    }
 
   return result;
 }
@@ -133,9 +141,16 @@ int U61_Protocol::send_all()
  */
 int U61_Protocol::recv_all()
 {
-  int result;
+  int result=U61_PROTOCOL_LATER;
 
-  while ((result=recv_next_packet())==U61_PROTOCOL_DONE);
+  if (!failed)
+    {
+      while ((result=recv_next_packet())==U61_PROTOCOL_DONE);
+      if (result==U61_PROTOCOL_FAILED)
+	{
+	  failed=true;
+	}
+    }
 
   return result;
 }
@@ -148,7 +163,9 @@ void U61_Protocol::reset()
 {
   stage=U61_PROTOCOL_BEGIN;
   step=0;
-  diagnostic="unknown problem";
+  diagnostic="unknown problem ";
+  connecting=false;
+  failed=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -175,13 +192,13 @@ int U61_Protocol::get_stage()
  * this is in theory useless since ClanLib does this checking but well,
  * I just enjoy checking 8-)
  */
-int U61_Protocol::send_id(U61_Connection *conn)
+int U61_Protocol::send_program(U61_Connection *conn)
 {
   int result=U61_PROTOCOL_LATER;
 
-  U61_LOG_DEBUG("Sending ID");
+  U61_LOG_DEBUG("Sending program");
 
-  if (conn->send(U61_PROTOCOL_GAME_ID,strlen(U61_PROTOCOL_GAME_ID)))
+  if (conn->send(U61_CONST_PROGRAM,strlen(U61_CONST_PROGRAM)))
     {
       result=U61_PROTOCOL_DONE;
     }
@@ -191,29 +208,29 @@ int U61_Protocol::send_id(U61_Connection *conn)
 
 /*--------------------------------------------------------------------------*/
 /*
- * receives the game ID (goes with send_id...)
+ * receives the game ID (goes with send_program...)
  */
-int U61_Protocol::recv_id(U61_Connection *conn)
+int U61_Protocol::recv_program(U61_Connection *conn)
 {
   int result=U61_PROTOCOL_LATER;
   char buffer[U61_CONST_STRING_SIZE];
 
-  U61_LOG_DEBUG("Receiving ID");
+  U61_LOG_DEBUG("Receiving program");
 
   if (conn->peek())
     {
       if (conn->recv(buffer,sizeof(buffer)-1))
 	{
-          if (strcmp(U61_PROTOCOL_GAME_ID,buffer)==0)
+          if (strcmp(U61_CONST_PROGRAM,buffer)==0)
 	    {
 	      result=U61_PROTOCOL_DONE;
-	      U61_LOG_DEBUG("Received ID "<<buffer<<"");
+	      U61_LOG_DEBUG("Received program "<<buffer<<"");
 	    }
           else
 	    {
 	      result=U61_PROTOCOL_FAILED;
-              diagnostic="Wrong ID, expecting \"";
-	      diagnostic+=U61_PROTOCOL_GAME_ID;
+              diagnostic="Wrong program, expecting \"";
+	      diagnostic+=U61_CONST_PROGRAM;
 	      diagnostic+="\" and received \"";
 	      diagnostic+=buffer;
 	      diagnostic+="\"";
@@ -348,3 +365,13 @@ void U61_Protocol::print_diagnostic()
   U61_LOG_WARNING("Network error : "<<diagnostic.c_str());
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Returns TRUE if the protocol is in a "connecting" stage
+ */
+bool U61_Protocol::is_connecting()
+{
+  return connecting;
+}
+
+
