@@ -64,13 +64,13 @@ class U61_Script
 
   static bool do_string(char *str);
   static bool do_file(char *file);
+  static char *get_global_str(char *name,char *def="");
   static int get_global_int(char *name,int def=0);
   static bool get_global_bool(char *name,bool def=false);
-  static char *get_global_str(char *name,char *def="");
 
   static bool init();
   static void collect_garbage();
-
+ 
   static bool check_id();
 
   static char *get_program();
@@ -97,6 +97,21 @@ class U61_Script
  protected:
   static void secure_pointers();
   static void record_all();
+
+  static bool execute_lua_void_func_void(char *func);
+  static bool execute_lua_void_func_int(char *func, 
+					int par1);
+  static bool execute_lua_void_func_int_int(char *func, 
+					    int par1, 
+					    int par2);
+  static bool execute_lua_int_func_int(int *result, 
+				       char *func, 
+				       int par1);
+  static bool execute_lua_string_func_void(char *result, 
+					   char *func);
+  static bool execute_lua_string_func_int(char *result,
+					  char *func, 
+					  int par1);
 };
 
 #endif
