@@ -119,42 +119,55 @@ void U61_ServerProtocol::check_connection()
   U61_Player *p;
   CL_NetComputer client;
   U61_Event evt;  
+  bool client_left=false;
 
   if (session!=NULL)
     {
-      client=(CL_NetComputer) session->receive_computer_leave();
-      for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
+      try 
 	{
-	  if (connection[i]!=NULL
-	      && connection[i]->is_associated(&client))
+	  client=(CL_NetComputer) session->receive_computer_leave();
+	  client_left=true;
+	}
+      catch (CL_Error e)
+	{
+	  U61_LOG_DEBUG("no client leaved the game, ClanLib says: "<<e.message.c_str());
+	}
+
+      if (client_left)
+	{
+	  for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
 	    {
-	      if (dispatcher!=NULL)
+	      if (connection[i]!=NULL
+		  && connection[i]->is_associated(&client))
 		{
-		  dispatcher->close(connection[i]);
-		}
-	      delete connection[i];
-
-	      evt.code=U61_EVENT_KILL;
-	      evt.time=0;
-	      evt.author=evt.target=id0[i];
-	      dispatcher->put_out(evt);   
-	      evt.author=evt.target=id1[i];
-	      dispatcher->put_out(evt);
-
-              p=U61_Global::game.find_player_by_id(id0[i]);
-              if (p!=NULL)
-		{
-                  p->kill();
-		}
-              p=U61_Global::game.find_player_by_id(id1[i]);
-              if (p!=NULL)
-		{
-                  p->kill();
-		}
-
-              connection[i]=NULL;
-              id0[i]=-1;
-              id1[i]=-1;   
+		  if (dispatcher!=NULL)
+		    {
+		      dispatcher->close(connection[i]);
+		    }
+		  delete connection[i];
+		  
+		  evt.code=U61_EVENT_KILL;
+		  evt.time=0;
+		  evt.author=evt.target=id0[i];
+		  dispatcher->put_out(evt);   
+		  evt.author=evt.target=id1[i];
+		  dispatcher->put_out(evt);
+		  
+		  p=U61_Global::game.find_player_by_id(id0[i]);
+		  if (p!=NULL)
+		    {
+		      p->kill();
+		    }
+		  p=U61_Global::game.find_player_by_id(id1[i]);
+		  if (p!=NULL)
+		    {
+		      p->kill();
+		    }
+		  
+		  connection[i]=NULL;
+		  id0[i]=-1;
+		  id1[i]=-1;  
+		} 
 	    } 
 	}
     }
