@@ -81,7 +81,7 @@ class U61_ServerProtocol : public U61_Protocol
   int send_curse_delay();
   int send_time();
 
-  void handle_error(int result);
+  void handle_error(int *result);
 };
 
 #endif
