@@ -40,6 +40,7 @@
 
 #include "sound.h"
 #include "global.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -66,6 +67,18 @@ void U61_Sound::play(CL_SoundBuffer *sound)
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * stops a sound being played
+ */
+void U61_Sound::stop(CL_SoundBuffer *sound)
+{
+  if (sound!=NULL)
+    {
+      sound->stop();
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * this sound is played when the game starts
@@ -138,3 +151,39 @@ void U61_Sound::play_player_loose()
   play(U61_Global::data.sound_player_loose);
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Wait until any played sound is ended. Required when exiting the game,
+ * otherwise SetupSound won't "deinit" correctly.
+ */
+void U61_Sound::wait_no_playback()
+{
+  stop(U61_Global::data.sound_game_start);
+  stop(U61_Global::data.sound_menu_move);
+  stop(U61_Global::data.sound_menu_validate);
+  stop(U61_Global::data.sound_block_touch);
+  stop(U61_Global::data.sound_block_pattern);
+  stop(U61_Global::data.sound_player_start);
+  stop(U61_Global::data.sound_curse_receive);
+  stop(U61_Global::data.sound_player_loose);
+
+  while ((U61_Global::data.sound_game_start &&
+	  U61_Global::data.sound_game_start->is_playing()) ||
+	 (U61_Global::data.sound_menu_move &&
+	  U61_Global::data.sound_menu_move->is_playing()) ||
+	 (U61_Global::data.sound_menu_validate &&
+	  U61_Global::data.sound_menu_validate->is_playing()) ||
+	 (U61_Global::data.sound_block_touch &&
+	  U61_Global::data.sound_block_touch->is_playing()) ||
+	 (U61_Global::data.sound_block_pattern &&
+	  U61_Global::data.sound_block_pattern->is_playing()) ||
+	 (U61_Global::data.sound_player_start &&
+	  U61_Global::data.sound_player_start->is_playing()) ||
+	 (U61_Global::data.sound_curse_receive &&
+	  U61_Global::data.sound_curse_receive->is_playing()) ||
+	 (U61_Global::data.sound_player_loose &&
+	  U61_Global::data.sound_player_loose->is_playing()))
+    {
+      CL_System::keep_alive(100);
+    }    
+}
