@@ -65,9 +65,11 @@ class U61_Sound
   static void play_player_start();
   static void play_curse_receive();
   static void play_player_loose();
+  static void wait_no_playback();
 
  protected:
   static void play(CL_SoundBuffer *sound);
+  static void stop(CL_SoundBuffer *sound);
 };
 
 #endif
