@@ -83,11 +83,25 @@ int U61_Utils::random(int scale)
 bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
 {
   bool ok=false;
+  char *requested_mode="";
+  char *alternate_mode="";
+
+  if (fullscreen)
+    {
+      requested_mode="fullscreen";
+      alternate_mode="windowed";
+    }
+  else
+    {
+      requested_mode="windowed";
+      alternate_mode="fullscreen";      
+    }
 
   if (!ok)
     {
       try 
 	{
+	  U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x16 "<<requested_mode<<"\".");
 	  CL_Display::set_videomode(w,h,16,fullscreen);
 	  ok=true;
 	}
@@ -95,6 +109,7 @@ bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
 	{
           try
 	    {
+	      U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x16 "<<alternate_mode<<"\".");
 	      CL_Display::set_videomode(w,h,16,!fullscreen);
 	      ok=true;
 	    }
@@ -102,6 +117,7 @@ bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
 	    {
 	      try
 		{
+		  U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x8 "<<requested_mode<<"\".");
 		  CL_Display::set_videomode(w,h,8,fullscreen);
 		  ok=true;
 		}
@@ -109,14 +125,13 @@ bool U61_Utils::set_videomode(int w,int h,bool fullscreen)
 		{
 		  try
 		    {
+		      U61_LOG_MESSAGE("Trying video mode \""<<w<<"x"<<h<<"x8 "<<alternate_mode<<"\".");
 		      CL_Display::set_videomode(w,h,8,!fullscreen);
 		      ok=true;
 		    }
 		  catch (CL_Error e)
 		    {
-		      U61_LOG_WARNING("Invalid video mode: w="<<w
-				      <<" h="<<h
-				      <<" fullscreen="<<fullscreen);
+		      U61_LOG_WARNING("Unable to set up a valid video mode");
 		    }
 		}
 	    }
