@@ -39,19 +39,17 @@
 
 #include "version.h"
 
-#include <stdio.h>
+#include <ctype.h>
+#include <string.h>
 
 /*---------------------------------------------------------------------------
  variants
  ---------------------------------------------------------------------------*/
 
 /*
- * these variables hold the version, for instance, 0.1.3 means than
- * version_1=0, version_2=1, version_3=3
+ * We store the version here
  */
-int U61_Version::version_1=U61_VERSION_1;
-int U61_Version::version_2=U61_VERSION_2;
-int U61_Version::version_3=U61_VERSION_3;
+char *U61_Version::version=U61_VERSION;
 
 /*---------------------------------------------------------------------------
  functions
@@ -63,7 +61,7 @@ int U61_Version::version_3=U61_VERSION_3;
  */
 void U61_Version::get_version_text(char *buffer)
 {
-    sprintf(buffer,"%d.%d.%d",version_1,version_2,version_3);
+    strcpy(buffer,version);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -72,33 +70,24 @@ void U61_Version::get_version_text(char *buffer)
  */
 int U61_Version::get_version_code()
 {
-    return version_1*1000000+version_2*1000+version_3;
+  int result=10;
+  char *pos;
+  int digit;
+
+  pos=version;
+  while (*pos)
+    {
+      if (isalnum(*pos))
+	{
+	  result*=100;
+	  digit=(*pos)-32;
+	  digit = (digit<0) ? 0 : digit;
+	  digit = (digit>99) ? 99 : digit;
+	  result+=digit;
+	}
+    }
+  
+  return result;
 }
 
-/*--------------------------------------------------------------------------*/
-/*
- * returns the first part of the version
- */
-int U61_Version::get_version_1()
-{
-    return version_1;
-}
-
-/*--------------------------------------------------------------------------*/
-/*
- * returns the second part of the version
- */
-int U61_Version::get_version_2()
-{
-    return version_2;
-}
-
-/*--------------------------------------------------------------------------*/
-/*
- * returns the last part of the version
- */
-int U61_Version::get_version_3()
-{
-    return version_3;
-}
 
